@@ -1,6 +1,6 @@
 package Bread::Board::Declare::Meta::Role::Accessor;
 BEGIN {
-  $Bread::Board::Declare::Meta::Role::Accessor::VERSION = '0.07';
+  $Bread::Board::Declare::Meta::Role::Accessor::VERSION = '0.08';
 }
 use Moose::Role;
 
@@ -37,15 +37,17 @@ Bread::Board::Declare::Meta::Role::Accessor
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
 =over 4
 
 =item *
 
-L<Bread::Board::Declare>
+L<Bread::Board::Declare|Bread::Board::Declare>
 
 =back
 
