@@ -1,6 +1,6 @@
 package Bread::Board::Declare::Role::Service;
 BEGIN {
-  $Bread::Board::Declare::Role::Service::VERSION = '0.07';
+  $Bread::Board::Declare::Role::Service::VERSION = '0.08';
 }
 use Moose::Role;
 # ABSTRACT: role for Bread::Board::Service objects
@@ -60,7 +60,7 @@ Bread::Board::Declare::Role::Service - role for Bread::Board::Service objects
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 DESCRIPTION
 
@@ -84,11 +84,13 @@ contained in.
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
 =over 4
 
 =item *
 
-L<Bread::Board::Declare>
+L<Bread::Board::Declare|Bread::Board::Declare>
 
 =back
 
